diff -urN galeon-1.3.14a.orig/src/galeon-window.c galeon-1.3.14a/src/galeon-window.c
--- galeon-1.3.14a.orig/src/galeon-window.c	2004-03-18 19:38:28.000000000 +0100
+++ galeon-1.3.14a/src/galeon-window.c	2004-04-22 16:22:17.000000000 +0200
@@ -208,6 +208,13 @@
 };
 static guint COOKIES_RADIO_SIZE = G_N_ELEMENTS(CookiesRadioGroup);
 
+static const char *ProxyRadioGroup[] = {
+	"WebProxyNoneAction",
+	"WebProxyManualAction",
+	"WebProxyAutoAction"
+};
+static guint PROXY_RADIO_SIZE = G_N_ELEMENTS(ProxyRadioGroup);
+
 static void
 egg_cmd_view_toolbar(EggAction *action, GaleonWindow *window)
 {
@@ -310,6 +317,9 @@
 static void
 web_cookies_policy_changed(EggAction *action, GaleonWindow *window);
 
+static void
+web_proxy_policy_changed(EggAction *action, GaleonWindow *window);
+
 static EggActionGroupEntry entries[] = {
 	{ "FileMenuAction", N_("_File"), NULL, NULL, NULL, NULL, NULL },
 	{ "EditMenuAction", N_("_Edit"), NULL, NULL, NULL, NULL, NULL },
@@ -320,6 +330,7 @@
 	{ "WebMenuAction", N_("_Web"), NULL, NULL, NULL, NULL, NULL },
 	{ "WebCookiesMenuAction", N_("C_ookies"), NULL, NULL, NULL, NULL, NULL },
 	{ "WebPopupsMenuAction", N_("_Popups"), NULL, NULL, NULL, NULL, NULL },
+	{ "WebProxyMenuAction", N_("Proxy"), NULL, NULL, NULL, NULL, NULL },
 	{ "GoMenuAction", N_("_Go"), NULL, NULL, NULL, NULL, NULL },
 	{ "BookmarksMenuAction", N_("_Bookmarks"), NULL, NULL, NULL, NULL, NULL },
 	{ "TabsMenuAction", N_("_Tabs"), NULL, NULL, NULL, NULL, NULL },
@@ -412,6 +423,16 @@
 	{ "WebJSConsoleAction", N_("J_avaScript Console"), NULL, NULL,
 	  N_("Show JavaScript console window"), G_CALLBACK(window_cmd_show_js_console), NULL },
 
+	{ "WebProxyNoneAction", N_("None"), NULL, NULL,
+	  N_("No Proxy"),
+	  G_CALLBACK(web_proxy_policy_changed), NULL, RADIO_ACTION },
+	{ "WebProxyManualAction", N_("Manual"), NULL, NULL,
+	  N_("Manual Proxy Settings"),
+	  G_CALLBACK(web_proxy_policy_changed), NULL, RADIO_ACTION, "WebProxyNoneAction"},
+	{ "WebProxyAutoAction", N_("Auto"),  NULL, NULL,
+	  N_("Automatic Proxy Settings"),
+	  G_CALLBACK(web_proxy_policy_changed), NULL, RADIO_ACTION, "WebProxyNoneAction"},
+
 	{ "WebCookiesBlockSiteAction", N_("_Block Cookies From This Site"), NULL, NULL,
 	  N_("Allow Cookies from this site to accepted"), G_CALLBACK(window_cmd_set_permission), NULL },
 	{ "WebCookiesAllowSiteAction", N_("_Allow Cookies From This Site"), NULL, NULL,
@@ -1059,6 +1080,26 @@
 }
 
 static void
+web_proxy_policy_changed(EggAction *action, GaleonWindow *window)
+{
+	const char *proxy_modes[3] = {"none", "manual", "auto"};
+
+	if (GALEON_TOGGLE_ACTION(action)->active == TRUE)
+	{
+		guint i;
+		for ( i=0 ; i<PROXY_RADIO_SIZE ; i++)
+		{
+			if(!strcmp(action->name, ProxyRadioGroup[i]))
+			{
+				eel_gconf_set_string(CONF_NETWORK_PROXY_MODE, 
+						      proxy_modes[i]);
+				break;
+			}
+		}
+	}
+}
+
+static void
 accept_cookies_gconf_changed_cb(GConfClient *client,
 				guint cnxn_id,
 				GConfEntry *entry,
diff -urN galeon-1.3.14a.orig/ui/galeon-egg-ui.xml galeon-1.3.14a/ui/galeon-egg-ui.xml
--- galeon-1.3.14a.orig/ui/galeon-egg-ui.xml	2004-02-12 23:04:37.000000000 +0100
+++ galeon-1.3.14a/ui/galeon-egg-ui.xml	2004-04-22 15:56:30.000000000 +0200
@@ -79,6 +79,12 @@
     		<separator name="WSep2" />
     		<menuitem name="WebPopupsAlways" verb="WebPopupsAlwaysAction" />
     	</submenu>
+	<submenu name="Proxy" verb="WebProxyMenuAction">
+		<menuitem name="ProxyTearoff" verb="Tearoff" />
+		<menuitem name="WebProxyNone" verb="WebProxyNoneAction" />
+		<menuitem name="WebProxyManual" verb="WebProxyManualAction" />
+		<menuitem name="WebProxyAuto" verb="WebProxyAutoAction" />
+	</submenu>
     	<separator name="WSep3" />
     	<menuitem name="WebAllowJava" verb="WebAllowJavaAction" />
     	<menuitem name="WebAllowJS" verb="WebAllowJSAction" />
